@@ -19,10 +19,15 @@ typedef enum {
    TOK_BACKGROUND,
    TOK_BUTTON,
    TOK_BUTTONCLOSE,
+   TOK_BUTTONCLOSEFOCUS,
    TOK_BUTTONMAX,
    TOK_BUTTONMAXACTIVE,
+   TOK_BUTTONMAXACTIVEFOCUS,
+   TOK_BUTTONMAXFOCUS,
    TOK_BUTTONMENU,
+   TOK_BUTTONMENUFOCUS,
    TOK_BUTTONMIN,
+   TOK_BUTTONMINFOCUS,
    TOK_CLASS,
    TOK_CLOCK,
    TOK_CLOCKSTYLE,
@@ -47,10 +52,13 @@ typedef enum {
    TOK_KEY,
    TOK_KILL,
    TOK_LAYER,
+   TOK_MACHINE,
    TOK_MAXIMIZE,
    TOK_MENU,
    TOK_MENUSTYLE,
    TOK_MINIMIZE,
+   TOK_MINIMIZED,
+   TOK_MOUSE,
    TOK_MOVE,
    TOK_MOVEMODE,
    TOK_NAME,
@@ -79,10 +87,13 @@ typedef enum {
    TOK_TASKLIST,
    TOK_TASKLISTSTYLE,
    TOK_TEXT,
+   TOK_TITLE,
+   TOK_TITLEBUTTONORDER,
    TOK_TRAY,
    TOK_TRAYBUTTON,
    TOK_TRAYBUTTONSTYLE,
    TOK_TRAYSTYLE,
+   TOK_TYPE,
    TOK_WIDTH,
    TOK_WINDOWSTYLE
 
